# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.percl_command import PerclCommand
from freeclimb.models.transcribe_utterance_record import TranscribeUtteranceRecord
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class TranscribeUtterance(
    PerclCommand,
    populate_by_name=True,
    validate_assignment=True,
    protected_namespaces=(),
):
    """
    The `TranscribeUtterance` command transcribes the caller’s voice and returns transcription of the audio and optionally returns the recording of the audio transcribed.  `TranscribeUtterance` is blocking and is a terminal command. As such, the actionUrl property is required, and control of the Call picks up using the `PerCL` returned in response of the `actionUrl`. Recording and Transcription information is returned in the actionUrl request. If the reason this command ended was due to the call hanging up, any PerCL returned will not execute.
    """  # noqa: E501

    action_url: StrictStr = Field(alias="actionUrl")
    play_beep: Optional[StrictBool] = Field(default=False, alias="playBeep")
    record: Optional[TranscribeUtteranceRecord] = None
    privacy_for_logging: Optional[StrictBool] = Field(
        default=False, alias="privacyForLogging"
    )
    privacy_for_recording: Optional[StrictBool] = Field(
        default=False, alias="privacyForRecording"
    )
    prompts: Optional[List[PerclCommand]] = None
    command: StrictStr = "TranscribeUtterance"

    __properties: ClassVar[List[str]] = [
        "command",
        "actionUrl",
        "playBeep",
        "record",
        "privacyForLogging",
        "privacyForRecording",
        "prompts",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TranscribeUtterance from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of record
        if self.record:
            _dict["record"] = self.record.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in prompts (list)
        _items = []
        if self.prompts:
            for _item_prompts in self.prompts:
                if _item_prompts:
                    _items.append(_item_prompts.to_dict())
            _dict["prompts"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TranscribeUtterance from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "command": obj.get("command"),
                "actionUrl": obj.get("actionUrl"),
                "playBeep": (
                    obj.get("playBeep") if obj.get("playBeep") is not None else False
                ),
                "record": (
                    TranscribeUtteranceRecord.from_dict(obj["record"])
                    if obj.get("record") is not None
                    else None
                ),
                "privacyForLogging": (
                    obj.get("privacyForLogging")
                    if obj.get("privacyForLogging") is not None
                    else False
                ),
                "privacyForRecording": (
                    obj.get("privacyForRecording")
                    if obj.get("privacyForRecording") is not None
                    else False
                ),
                "prompts": (
                    [PerclCommand.from_dict(_item) for _item in obj["prompts"]]
                    if obj.get("prompts") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.application_result import ApplicationResult
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class ApplicationList(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    ApplicationList
    """  # noqa: E501

    total: Optional[StrictInt] = Field(
        default=None, description="Total amount of requested resource."
    )
    start: Optional[StrictInt] = Field(
        default=None, description="Resource index at start of current page"
    )
    end: Optional[StrictInt] = Field(
        default=None, description="Resource index at end of current page"
    )
    page: Optional[StrictInt] = Field(default=None, description="Current page")
    num_pages: Optional[StrictInt] = Field(
        default=None, description="Total number of pages", alias="numPages"
    )
    page_size: Optional[StrictInt] = Field(
        default=None, description="Number of items per page", alias="pageSize"
    )
    next_page_uri: Optional[StrictStr] = Field(
        default=None,
        description="Uri to retrieve the next page of items",
        alias="nextPageUri",
    )
    applications: Optional[List[ApplicationResult]] = None

    __properties: ClassVar[List[str]] = [
        "total",
        "start",
        "end",
        "page",
        "numPages",
        "pageSize",
        "nextPageUri",
        "applications",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApplicationList from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in applications (list)
        _items = []
        if self.applications:
            for _item_applications in self.applications:
                if _item_applications:
                    _items.append(_item_applications.to_dict())
            _dict["applications"] = _items
        # set to None if total (nullable) is None
        # and model_fields_set contains the field
        if self.total is None and "total" in self.model_fields_set:
            _dict["total"] = None

        # set to None if start (nullable) is None
        # and model_fields_set contains the field
        if self.start is None and "start" in self.model_fields_set:
            _dict["start"] = None

        # set to None if end (nullable) is None
        # and model_fields_set contains the field
        if self.end is None and "end" in self.model_fields_set:
            _dict["end"] = None

        # set to None if page (nullable) is None
        # and model_fields_set contains the field
        if self.page is None and "page" in self.model_fields_set:
            _dict["page"] = None

        # set to None if num_pages (nullable) is None
        # and model_fields_set contains the field
        if self.num_pages is None and "num_pages" in self.model_fields_set:
            _dict["numPages"] = None

        # set to None if page_size (nullable) is None
        # and model_fields_set contains the field
        if self.page_size is None and "page_size" in self.model_fields_set:
            _dict["pageSize"] = None

        # set to None if next_page_uri (nullable) is None
        # and model_fields_set contains the field
        if self.next_page_uri is None and "next_page_uri" in self.model_fields_set:
            _dict["nextPageUri"] = None

        # set to None if applications (nullable) is None
        # and model_fields_set contains the field
        if self.applications is None and "applications" in self.model_fields_set:
            _dict["applications"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApplicationList from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "total": obj.get("total"),
                "start": obj.get("start"),
                "end": obj.get("end"),
                "page": obj.get("page"),
                "numPages": obj.get("numPages"),
                "pageSize": obj.get("pageSize"),
                "nextPageUri": obj.get("nextPageUri"),
                "applications": (
                    [
                        ApplicationResult.from_dict(_item)
                        for _item in obj["applications"]
                    ]
                    if obj.get("applications") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from freeclimb.models.sms_ten_dlc_brand_alt_business_id_type import (
    SMSTenDLCBrandAltBusinessIdType,
)
from freeclimb.models.sms_ten_dlc_brand_entity_type import SMSTenDLCBrandEntityType
from freeclimb.models.sms_ten_dlc_brand_identity_status import (
    SMSTenDLCBrandIdentityStatus,
)
from freeclimb.models.sms_ten_dlc_brand_relationship import SMSTenDLCBrandRelationship
from freeclimb.models.sms_ten_dlc_brand_stock_exchange import (
    SMSTenDLCBrandStockExchange,
)
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class SMSTenDLCBrand(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    A brand is a business identity behind the campaign.
    """  # noqa: E501

    account_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the account that created this Queue.",
        alias="accountId",
    )
    entity_type: SMSTenDLCBrandEntityType = Field(alias="entityType")
    csp_id: Optional[StrictStr] = Field(
        default=None,
        description="Unique identifier assigned to the csp by the registry.",
        alias="cspId",
    )
    brand_id: Optional[StrictStr] = Field(
        default=None,
        description="Unique identifier assigned to the brand by the registry.",
        alias="brandId",
    )
    first_name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(
        default=None, description="First or given name. ", alias="firstName"
    )
    last_name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(
        default=None, description="Last or Surname.", alias="lastName"
    )
    display_name: Annotated[str, Field(strict=True, max_length=255)] = Field(
        description="Display or marketing name of the brand.", alias="displayName"
    )
    company_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(
        default=None,
        description="(Required for Non-profit/private/public) Legal company name.",
        alias="companyName",
    )
    ein: Optional[Annotated[str, Field(strict=True, max_length=21)]] = Field(
        default=None,
        description="(Required for Non-profit) Government assigned corporate tax ID. EIN is 9-digits in U.S.",
    )
    ein_issuing_country: Optional[Annotated[str, Field(strict=True, max_length=2)]] = (
        Field(
            default=None,
            description="ISO2 2 characters country code. Example: US - United States",
            alias="einIssuingCountry",
        )
    )
    phone: Annotated[str, Field(strict=True, max_length=20)] = Field(
        description="Valid phone number in e.164 international format."
    )
    street: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(
        default=None, description="Street number and name."
    )
    city: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(
        default=None, description="City name"
    )
    state: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(
        default=None, description="State. Must be 2 letters code for United States."
    )
    postal_code: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(
        default=None,
        description="Postal codes. Use 5 digit zipcode for United States",
        alias="postalCode",
    )
    country: Annotated[str, Field(strict=True, max_length=2)] = Field(
        description="ISO2 2 characters country code. Example: US - United States"
    )
    email: Annotated[str, Field(strict=True, max_length=100)] = Field(
        description="Valid email address of brand support contact."
    )
    stock_symbol: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(
        default=None,
        description="(Required for public company) stock symbol.",
        alias="stockSymbol",
    )
    stock_exchange: Optional[SMSTenDLCBrandStockExchange] = Field(
        default=None, alias="stockExchange"
    )
    ip_address: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(
        default=None,
        description="IP address of the browser requesting to create brand identity.",
        alias="ipAddress",
    )
    website: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(
        default=None, description="Brand website URL."
    )
    brand_relationship: SMSTenDLCBrandRelationship = Field(alias="brandRelationship")
    vertical: Annotated[str, Field(strict=True, max_length=50)] = Field(
        description="Vertical or industry segment of the brand."
    )
    alt_business_id: Optional[Annotated[str, Field(strict=True, max_length=50)]] = (
        Field(
            default=None,
            description="Alternate business identifier such as DUNS, LEI, or GIIN",
            alias="altBusinessId",
        )
    )
    alt_business_id_type: Optional[SMSTenDLCBrandAltBusinessIdType] = Field(
        default=None, alias="altBusinessIdType"
    )
    universal_ein: Optional[StrictStr] = Field(
        default=None,
        description="Universal EIN of Brand, Read Only.",
        alias="universalEin",
    )
    reference_id: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(
        default=None,
        description="Caller supplied brand reference ID. If supplied, the value must be unique across all submitted brands. Can be used to prevent duplicate brand registrations.",
        alias="referenceId",
    )
    optional_attributes: Optional[Dict[str, Any]] = Field(
        default=None,
        description="Optional brand attributes. Please refer to GET /enum/optionalAttributeNames for dictionary of optional attribute names.",
        alias="optionalAttributes",
    )
    mock: StrictBool = Field(description="Test brand.")
    identity_status: SMSTenDLCBrandIdentityStatus = Field(alias="identityStatus")
    create_date: Optional[datetime] = Field(
        default=None,
        description="Unix timestamp when brand was created.",
        alias="createDate",
    )

    __properties: ClassVar[List[str]] = [
        "accountId",
        "entityType",
        "cspId",
        "brandId",
        "firstName",
        "lastName",
        "displayName",
        "companyName",
        "ein",
        "einIssuingCountry",
        "phone",
        "street",
        "city",
        "state",
        "postalCode",
        "country",
        "email",
        "stockSymbol",
        "stockExchange",
        "ipAddress",
        "website",
        "brandRelationship",
        "vertical",
        "altBusinessId",
        "altBusinessIdType",
        "universalEin",
        "referenceId",
        "optionalAttributes",
        "mock",
        "identityStatus",
        "createDate",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SMSTenDLCBrand from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set(
            [
                "csp_id",
                "brand_id",
                "universal_ein",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SMSTenDLCBrand from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accountId": obj.get("accountId"),
                "entityType": obj.get("entityType"),
                "cspId": obj.get("cspId"),
                "brandId": obj.get("brandId"),
                "firstName": obj.get("firstName"),
                "lastName": obj.get("lastName"),
                "displayName": obj.get("displayName"),
                "companyName": obj.get("companyName"),
                "ein": obj.get("ein"),
                "einIssuingCountry": obj.get("einIssuingCountry"),
                "phone": obj.get("phone"),
                "street": obj.get("street"),
                "city": obj.get("city"),
                "state": obj.get("state"),
                "postalCode": obj.get("postalCode"),
                "country": obj.get("country"),
                "email": obj.get("email"),
                "stockSymbol": obj.get("stockSymbol"),
                "stockExchange": obj.get("stockExchange"),
                "ipAddress": obj.get("ipAddress"),
                "website": obj.get("website"),
                "brandRelationship": obj.get("brandRelationship"),
                "vertical": obj.get("vertical"),
                "altBusinessId": obj.get("altBusinessId"),
                "altBusinessIdType": obj.get("altBusinessIdType"),
                "universalEin": obj.get("universalEin"),
                "referenceId": obj.get("referenceId"),
                "optionalAttributes": obj.get("optionalAttributes"),
                "mock": obj.get("mock"),
                "identityStatus": obj.get("identityStatus"),
                "createDate": obj.get("createDate"),
            }
        )
        return _obj



import sys
import time
import unittest

from freeclimb.utils.request_verifier import RequestVerifier


class TestRequestVerifier(unittest.TestCase):
    """RequestVerifier unit test stubs"""

    def setUp(self):
        self.request_verifier = RequestVerifier()

    def tearDown(self):
        pass

    def test_check_request_body(self):
        request_body = ""
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(str(exc.exception), "Request Body cannot be empty or null")

    def test_check_request_header_no_signatures(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "t=1679944186,"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(
            str(exc.exception), "Error with request header, signatures are not present"
        )

    def test_check_request_header_no_timestamp(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(
            str(exc.exception), "Error with request header, timestamp is not present"
        )

    def test_check_request_header_empty_request_header(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = ""
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(
            str(exc.exception), "Error with request header, Request header is empty"
        )

    def test_check_signing_secret(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = ""
        tolerance = 5 * 60 * 1000
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(str(exc.exception), "Signing secret cannot be empty or null")

    def test_check_tolerance_max_int(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = sys.maxsize
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(
            str(exc.exception), "Tolerance value must be a positive integer"
        )

    def test_check_tolerance_zero_value(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 0
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        with self.assertRaises(Exception) as exc:
            self.request_verifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(
            str(exc.exception), "Tolerance value must be a positive integer"
        )

    def test_check_tolerance_negative_value(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = -5
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(
            str(exc.exception), "Tolerance value must be a positive integer"
        )

    def test_verify_tolerance(self):
        current_time = int(time.time())
        request_header_time = current_time - (6 * 60 * 1000)
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = (
            "t="
            + str(request_header_time)
            + ",v1=1d798c86e977ff734dec3a8b8d67fe8621dcc1df46ef4212e0bfe2e122b01bfd,v1=78e363373f8a9f6fddc2e3ca3a1ed9dc94efa44d378363adf52434e78f32d8fb"
        )
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(
            str(exc.exception),
            "Request time exceeded tolerance threshold. Request: "
            + str(request_header_time)
            + ", CurrentTime: "
            + str(current_time)
            + ", tolerance: "
            + str(tolerance),
        )

    def test_verify_signature(self):
        current_time = int(time.time())
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7794"
        tolerance = 5 * 60 * 1000
        request_header = (
            "t="
            + str(current_time)
            + ",v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        )
        with self.assertRaises(Exception) as exc:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        self.assertEqual(
            str(exc.exception),
            "Unverified signature request, If this request was unexpected, it may be from a bad actor. Please proceed with caution. If the request was exepected, please check any typos or issues with the signingSecret",
        )

    def test_verify_request_signature(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        tolerance = 5 * 60 * 1000
        request_header = "t=3795106129,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=96b769b34426fa69117dd6d1bda2c432beb2cf4c63dd2de495fca0c37dde82b2"
        raised = False
        try:
            RequestVerifier.verify_request_signature(
                request_body, request_header, signing_secret, tolerance
            )
        except:
            raised = True
            self.assertFalse(raised, "Exception has been raised")


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.barge_in_reason import BargeInReason
from freeclimb.models.record_utterance_term_reason import RecordUtteranceTermReason
from freeclimb.models.transcribe_reason import TranscribeReason
from freeclimb.models.transcribe_term_reason import TranscribeTermReason
from freeclimb.models.webhook import Webhook
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class TranscribeWebhook(
    Webhook, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    TranscribeWebhook
    """  # noqa: E501

    request_type: Optional[StrictStr] = Field(
        default=None,
        description="The context or reason why this request is being made. Will be transcribe - The TranscribeUtterance command has completed and its actionUrl is being invoked.",
        alias="requestType",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="Account ID associated with your account.",
        alias="accountId",
    )
    call_id: Optional[StrictStr] = Field(
        default=None,
        description="Unique identifier for this Call, generated by FreeClimb",
        alias="callId",
    )
    var_from: Optional[StrictStr] = Field(
        default=None,
        description="Phone number of the party that initiated the Call (in E.164 format).",
        alias="from",
    )
    to: Optional[StrictStr] = Field(
        default=None,
        description="Phone number provisioned to the customer and to which this Call is directed (in E.164 format).",
    )
    recording_id: Optional[StrictStr] = Field(
        default=None,
        description="The ID of the recording. If no recording was made due to errors or the 'saveRecording' flag being disabled this field will be set to null.",
        alias="recordingId",
    )
    recording_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL of the recorded audio file. This URL can be used as is in a Play command to play the recording (no authentication needed). It can also be used to download the recording file via the REST API.",
        alias="recordingUrl",
    )
    recording_size: Optional[StrictInt] = Field(
        default=None,
        description="The size of the recording in bytes.",
        alias="recordingSize",
    )
    recording_format: Optional[StrictStr] = Field(
        default=None,
        description="The media type of the recording.",
        alias="recordingFormat",
    )
    recording_duration_ms: Optional[StrictInt] = Field(
        default=None,
        description="The duration of the recorded audio in milliseconds.",
        alias="recordingDurationMs",
    )
    term_reason: Optional[TranscribeTermReason] = Field(
        default=None, alias="termReason"
    )
    record_term_reason: Optional[RecordUtteranceTermReason] = Field(
        default=None, alias="recordTermReason"
    )
    digit: Optional[StrictStr] = Field(
        default=None,
        description="If recordTermReason is digit, this will be the digit that was pressed. Otherwise it will be null.",
    )
    privacy_for_logging: Optional[StrictBool] = Field(
        default=None,
        description="Echo back of the privacyForLogging flag as specified in the transcribe utterance command – confirmation of logging protection has been applied. Can be used by application to know it should also apply protection when handling this request.",
        alias="privacyForLogging",
    )
    privacy_for_recording: Optional[StrictBool] = Field(
        default=None,
        description="Echo back of the privacyForRecording flag as specified in the transcribe utterance command – confirmation of logging protection has been applied. Can be used by application to know it should also apply protection when handling this request.",
        alias="privacyForRecording",
    )
    barge_in_reason: Optional[BargeInReason] = Field(
        default=None, alias="bargeInReason"
    )
    barged_in_prompt_no: Optional[StrictInt] = Field(
        default=None, alias="bargedInPromptNo"
    )
    barged_in_prompt_ms: Optional[StrictInt] = Field(
        default=None,
        description="duration in ms bargedInPromptNo prompt was executing until barge-in occurred.",
        alias="bargedInPromptMs",
    )
    barged_in_prompt_loop_no: Optional[StrictInt] = Field(
        default=None, alias="bargedInPromptLoopNo"
    )
    barge_in_time_ms: Optional[StrictInt] = Field(
        default=None, description="epoch time in ms", alias="bargeInTimeMs"
    )
    transcript: Optional[StrictStr] = Field(
        default=None,
        description="Transcribed text of the recording. Can be empty or null. null means there was a failure in transcribing the audio, refer to transcribeReason for detailed failure reason.",
    )
    transcribe_reason: Optional[TranscribeReason] = Field(
        default=None, alias="transcribeReason"
    )
    transcription_duration_ms: Optional[StrictInt] = Field(
        default=None,
        description="The duration of the audio being transcribed in milliseconds",
        alias="transcriptionDurationMs",
    )

    __properties: ClassVar[List[str]] = [
        "requestType",
        "accountId",
        "callId",
        "from",
        "to",
        "recordingId",
        "recordingUrl",
        "recordingSize",
        "recordingFormat",
        "recordingDurationMs",
        "termReason",
        "recordTermReason",
        "digit",
        "privacyForLogging",
        "privacyForRecording",
        "bargeInReason",
        "bargedInPromptNo",
        "bargedInPromptMs",
        "bargedInPromptLoopNo",
        "bargeInTimeMs",
        "transcript",
        "transcribeReason",
        "transcriptionDurationMs",
    ]

    @classmethod
    def deserialize(cls, payload: str) -> Optional[Self]:
        return cls.from_json(payload)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TranscribeWebhook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if recording_id (nullable) is None
        # and model_fields_set contains the field
        if self.recording_id is None and "recording_id" in self.model_fields_set:
            _dict["recordingId"] = None

        # set to None if recording_url (nullable) is None
        # and model_fields_set contains the field
        if self.recording_url is None and "recording_url" in self.model_fields_set:
            _dict["recordingUrl"] = None

        # set to None if recording_format (nullable) is None
        # and model_fields_set contains the field
        if (
            self.recording_format is None
            and "recording_format" in self.model_fields_set
        ):
            _dict["recordingFormat"] = None

        # set to None if digit (nullable) is None
        # and model_fields_set contains the field
        if self.digit is None and "digit" in self.model_fields_set:
            _dict["digit"] = None

        # set to None if transcript (nullable) is None
        # and model_fields_set contains the field
        if self.transcript is None and "transcript" in self.model_fields_set:
            _dict["transcript"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TranscribeWebhook from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "requestType": obj.get("requestType"),
                "accountId": obj.get("accountId"),
                "callId": obj.get("callId"),
                "from": obj.get("from"),
                "to": obj.get("to"),
                "recordingId": obj.get("recordingId"),
                "recordingUrl": obj.get("recordingUrl"),
                "recordingSize": obj.get("recordingSize"),
                "recordingFormat": obj.get("recordingFormat"),
                "recordingDurationMs": obj.get("recordingDurationMs"),
                "termReason": obj.get("termReason"),
                "recordTermReason": obj.get("recordTermReason"),
                "digit": obj.get("digit"),
                "privacyForLogging": obj.get("privacyForLogging"),
                "privacyForRecording": obj.get("privacyForRecording"),
                "bargeInReason": obj.get("bargeInReason"),
                "bargedInPromptNo": obj.get("bargedInPromptNo"),
                "bargedInPromptMs": obj.get("bargedInPromptMs"),
                "bargedInPromptLoopNo": obj.get("bargedInPromptLoopNo"),
                "bargeInTimeMs": obj.get("bargeInTimeMs"),
                "transcript": obj.get("transcript"),
                "transcribeReason": obj.get("transcribeReason"),
                "transcriptionDurationMs": obj.get("transcriptionDurationMs"),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "5.1.1"

# import apis into sdk package
from freeclimb.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from freeclimb.api_response import ApiResponse
from freeclimb.api_client import ApiClient
from freeclimb.configuration import Configuration
from freeclimb.exceptions import OpenApiException
from freeclimb.exceptions import ApiTypeError
from freeclimb.exceptions import ApiValueError
from freeclimb.exceptions import ApiKeyError
from freeclimb.exceptions import ApiAttributeError
from freeclimb.exceptions import ApiException

# import models into sdk package
from freeclimb.models.account_request import AccountRequest as AccountRequest
from freeclimb.models.account_result import AccountResult as AccountResult
from freeclimb.models.account_status import AccountStatus as AccountStatus
from freeclimb.models.account_type import AccountType as AccountType
from freeclimb.models.add_to_conference import AddToConference as AddToConference
from freeclimb.models.add_to_conference_notification_webhook import (
    AddToConferenceNotificationWebhook as AddToConferenceNotificationWebhook,
)
from freeclimb.models.add_to_queue_notification_webhook import (
    AddToQueueNotificationWebhook as AddToQueueNotificationWebhook,
)
from freeclimb.models.answered_by import AnsweredBy as AnsweredBy
from freeclimb.models.application_list import ApplicationList as ApplicationList
from freeclimb.models.application_request import (
    ApplicationRequest as ApplicationRequest,
)
from freeclimb.models.application_result import ApplicationResult as ApplicationResult
from freeclimb.models.available_number import AvailableNumber as AvailableNumber
from freeclimb.models.available_number_list import (
    AvailableNumberList as AvailableNumberList,
)
from freeclimb.models.barge_in_reason import BargeInReason as BargeInReason
from freeclimb.models.buy_incoming_number_request import (
    BuyIncomingNumberRequest as BuyIncomingNumberRequest,
)
from freeclimb.models.call_control_webhook import (
    CallControlWebhook as CallControlWebhook,
)
from freeclimb.models.call_direction import CallDirection as CallDirection
from freeclimb.models.call_ended_reason import CallEndedReason as CallEndedReason
from freeclimb.models.call_list import CallList as CallList
from freeclimb.models.call_result import CallResult as CallResult
from freeclimb.models.call_status import CallStatus as CallStatus
from freeclimb.models.call_status_webhook import CallStatusWebhook as CallStatusWebhook
from freeclimb.models.capabilities import Capabilities as Capabilities
from freeclimb.models.completion_request import CompletionRequest as CompletionRequest
from freeclimb.models.completion_result import CompletionResult as CompletionResult
from freeclimb.models.completion_result_status import (
    CompletionResultStatus as CompletionResultStatus,
)
from freeclimb.models.conference_list import ConferenceList as ConferenceList
from freeclimb.models.conference_participant_list import (
    ConferenceParticipantList as ConferenceParticipantList,
)
from freeclimb.models.conference_participant_result import (
    ConferenceParticipantResult as ConferenceParticipantResult,
)
from freeclimb.models.conference_recording_status_webhook import (
    ConferenceRecordingStatusWebhook as ConferenceRecordingStatusWebhook,
)
from freeclimb.models.conference_result import ConferenceResult as ConferenceResult
from freeclimb.models.conference_status import ConferenceStatus as ConferenceStatus
from freeclimb.models.conference_status_webhook import (
    ConferenceStatusWebhook as ConferenceStatusWebhook,
)
from freeclimb.models.create_conference import CreateConference as CreateConference
from freeclimb.models.create_conference_request import (
    CreateConferenceRequest as CreateConferenceRequest,
)
from freeclimb.models.create_conference_webhook import (
    CreateConferenceWebhook as CreateConferenceWebhook,
)
from freeclimb.models.create_web_rtc_token import CreateWebRTCToken as CreateWebRTCToken
from freeclimb.models.dequeue import Dequeue as Dequeue
from freeclimb.models.dequeue_webhook import DequeueWebhook as DequeueWebhook
from freeclimb.models.enqueue import Enqueue as Enqueue
from freeclimb.models.filter_logs_request import FilterLogsRequest as FilterLogsRequest
from freeclimb.models.get_digits import GetDigits as GetDigits
from freeclimb.models.get_digits_reason import GetDigitsReason as GetDigitsReason
from freeclimb.models.get_digits_webhook import GetDigitsWebhook as GetDigitsWebhook
from freeclimb.models.get_speech import GetSpeech as GetSpeech
from freeclimb.models.get_speech_reason import GetSpeechReason as GetSpeechReason
from freeclimb.models.get_speech_webhook import GetSpeechWebhook as GetSpeechWebhook
from freeclimb.models.grammar_file_built_in import (
    GrammarFileBuiltIn as GrammarFileBuiltIn,
)
from freeclimb.models.grammar_type import GrammarType as GrammarType
from freeclimb.models.hangup import Hangup as Hangup
from freeclimb.models.if_machine import IfMachine as IfMachine
from freeclimb.models.inbound_call_webhook import (
    InboundCallWebhook as InboundCallWebhook,
)
from freeclimb.models.incoming_number_list import (
    IncomingNumberList as IncomingNumberList,
)
from freeclimb.models.incoming_number_request import (
    IncomingNumberRequest as IncomingNumberRequest,
)
from freeclimb.models.incoming_number_result import (
    IncomingNumberResult as IncomingNumberResult,
)
from freeclimb.models.language import Language as Language
from freeclimb.models.leave_conference_webhook import (
    LeaveConferenceWebhook as LeaveConferenceWebhook,
)
from freeclimb.models.log_level import LogLevel as LogLevel
from freeclimb.models.log_list import LogList as LogList
from freeclimb.models.log_result import LogResult as LogResult
from freeclimb.models.machine_detected_webhook import (
    MachineDetectedWebhook as MachineDetectedWebhook,
)
from freeclimb.models.machine_type import MachineType as MachineType
from freeclimb.models.make_call_request import MakeCallRequest as MakeCallRequest
from freeclimb.models.message_delivery_webhook import (
    MessageDeliveryWebhook as MessageDeliveryWebhook,
)
from freeclimb.models.message_direction import MessageDirection as MessageDirection
from freeclimb.models.message_request import MessageRequest as MessageRequest
from freeclimb.models.message_result import MessageResult as MessageResult
from freeclimb.models.message_status import MessageStatus as MessageStatus
from freeclimb.models.message_status_webhook import (
    MessageStatusWebhook as MessageStatusWebhook,
)
from freeclimb.models.messages_list import MessagesList as MessagesList
from freeclimb.models.mutable_resource_model import (
    MutableResourceModel as MutableResourceModel,
)
from freeclimb.models.out_dial import OutDial as OutDial
from freeclimb.models.out_dial_api_connect_webhook import (
    OutDialApiConnectWebhook as OutDialApiConnectWebhook,
)
from freeclimb.models.out_dial_connect_webhook import (
    OutDialConnectWebhook as OutDialConnectWebhook,
)
from freeclimb.models.out_dial_start_webhook import (
    OutDialStartWebhook as OutDialStartWebhook,
)
from freeclimb.models.pagination_model import PaginationModel as PaginationModel
from freeclimb.models.park import Park as Park
from freeclimb.models.pause import Pause as Pause
from freeclimb.models.percl_command import PerclCommand as PerclCommand
from freeclimb.models.percl_script import PerclScript as PerclScript
from freeclimb.models.play import Play as Play
from freeclimb.models.play_beep import PlayBeep as PlayBeep
from freeclimb.models.play_early_media import PlayEarlyMedia as PlayEarlyMedia
from freeclimb.models.queue_list import QueueList as QueueList
from freeclimb.models.queue_member import QueueMember as QueueMember
from freeclimb.models.queue_member_list import QueueMemberList as QueueMemberList
from freeclimb.models.queue_request import QueueRequest as QueueRequest
from freeclimb.models.queue_result import QueueResult as QueueResult
from freeclimb.models.queue_result_status import QueueResultStatus as QueueResultStatus
from freeclimb.models.queue_wait_webhook import QueueWaitWebhook as QueueWaitWebhook
from freeclimb.models.record_utterance import RecordUtterance as RecordUtterance
from freeclimb.models.record_utterance_term_reason import (
    RecordUtteranceTermReason as RecordUtteranceTermReason,
)
from freeclimb.models.record_webhook import RecordWebhook as RecordWebhook
from freeclimb.models.recording_list import RecordingList as RecordingList
from freeclimb.models.recording_result import RecordingResult as RecordingResult
from freeclimb.models.redirect import Redirect as Redirect
from freeclimb.models.redirect_webhook import RedirectWebhook as RedirectWebhook
from freeclimb.models.reject import Reject as Reject
from freeclimb.models.remove_from_conference import (
    RemoveFromConference as RemoveFromConference,
)
from freeclimb.models.remove_from_queue_notification_webhook import (
    RemoveFromQueueNotificationWebhook as RemoveFromQueueNotificationWebhook,
)
from freeclimb.models.request_type import RequestType as RequestType
from freeclimb.models.sms_ten_dlc_brand import SMSTenDLCBrand as SMSTenDLCBrand
from freeclimb.models.sms_ten_dlc_brand_alt_business_id_type import (
    SMSTenDLCBrandAltBusinessIdType as SMSTenDLCBrandAltBusinessIdType,
)
from freeclimb.models.sms_ten_dlc_brand_entity_type import (
    SMSTenDLCBrandEntityType as SMSTenDLCBrandEntityType,
)
from freeclimb.models.sms_ten_dlc_brand_identity_status import (
    SMSTenDLCBrandIdentityStatus as SMSTenDLCBrandIdentityStatus,
)
from freeclimb.models.sms_ten_dlc_brand_relationship import (
    SMSTenDLCBrandRelationship as SMSTenDLCBrandRelationship,
)
from freeclimb.models.sms_ten_dlc_brand_stock_exchange import (
    SMSTenDLCBrandStockExchange as SMSTenDLCBrandStockExchange,
)
from freeclimb.models.sms_ten_dlc_brands_list_result import (
    SMSTenDLCBrandsListResult as SMSTenDLCBrandsListResult,
)
from freeclimb.models.sms_ten_dlc_campaign import SMSTenDLCCampaign as SMSTenDLCCampaign
from freeclimb.models.sms_ten_dlc_campaign_status import (
    SMSTenDLCCampaignStatus as SMSTenDLCCampaignStatus,
)
from freeclimb.models.sms_ten_dlc_campaigns_list_result import (
    SMSTenDLCCampaignsListResult as SMSTenDLCCampaignsListResult,
)
from freeclimb.models.sms_ten_dlc_partner_campaign import (
    SMSTenDLCPartnerCampaign as SMSTenDLCPartnerCampaign,
)
from freeclimb.models.sms_ten_dlc_partner_campaign_brand import (
    SMSTenDLCPartnerCampaignBrand as SMSTenDLCPartnerCampaignBrand,
)
from freeclimb.models.sms_ten_dlc_partner_campaign_status import (
    SMSTenDLCPartnerCampaignStatus as SMSTenDLCPartnerCampaignStatus,
)
from freeclimb.models.sms_ten_dlc_partner_campaigns_list_result import (
    SMSTenDLCPartnerCampaignsListResult as SMSTenDLCPartnerCampaignsListResult,
)
from freeclimb.models.sms_toll_free_campaign import (
    SMSTollFreeCampaign as SMSTollFreeCampaign,
)
from freeclimb.models.sms_toll_free_campaign_registration_status import (
    SMSTollFreeCampaignRegistrationStatus as SMSTollFreeCampaignRegistrationStatus,
)
from freeclimb.models.sms_toll_free_campaigns_list_result import (
    SMSTollFreeCampaignsListResult as SMSTollFreeCampaignsListResult,
)
from freeclimb.models.say import Say as Say
from freeclimb.models.send_digits import SendDigits as SendDigits
from freeclimb.models.set_dtmf_pass_through import (
    SetDTMFPassThrough as SetDTMFPassThrough,
)
from freeclimb.models.set_listen import SetListen as SetListen
from freeclimb.models.set_talk import SetTalk as SetTalk
from freeclimb.models.sms import Sms as Sms
from freeclimb.models.start_record_call import StartRecordCall as StartRecordCall
from freeclimb.models.tfn import TFN as TFN
from freeclimb.models.tfn_campaign import TFNCampaign as TFNCampaign
from freeclimb.models.terminate_conference import (
    TerminateConference as TerminateConference,
)
from freeclimb.models.transcribe_reason import TranscribeReason as TranscribeReason
from freeclimb.models.transcribe_term_reason import (
    TranscribeTermReason as TranscribeTermReason,
)
from freeclimb.models.transcribe_utterance import (
    TranscribeUtterance as TranscribeUtterance,
)
from freeclimb.models.transcribe_utterance_record import (
    TranscribeUtteranceRecord as TranscribeUtteranceRecord,
)
from freeclimb.models.transcribe_webhook import TranscribeWebhook as TranscribeWebhook
from freeclimb.models.unpark import Unpark as Unpark
from freeclimb.models.update_call_request import UpdateCallRequest as UpdateCallRequest
from freeclimb.models.update_call_request_status import (
    UpdateCallRequestStatus as UpdateCallRequestStatus,
)
from freeclimb.models.update_conference_participant_request import (
    UpdateConferenceParticipantRequest as UpdateConferenceParticipantRequest,
)
from freeclimb.models.update_conference_request import (
    UpdateConferenceRequest as UpdateConferenceRequest,
)
from freeclimb.models.update_conference_request_status import (
    UpdateConferenceRequestStatus as UpdateConferenceRequestStatus,
)
from freeclimb.models.webhook import Webhook as Webhook



import time, hmac, hashlib


class SignatureInformation:
    request_timestamp: int = 0
    signatures = []

    def __init__(self, request_header: str):
        signature_headers = request_header.split(",")
        for signature in signature_headers:
            header, value = signature.split("=")
            if header == "t":
                self.request_timestamp = int(value)
            elif header == "v1":
                self.signatures.append(value)

    def is_request_time_valid(self, tolerance: int) -> bool:
        current_time = self.get_current_unix_time()
        time_calculation: int = self.request_timestamp + tolerance
        return current_time < (time_calculation)

    def is_signature_safe(self, requestBody: str, signingSecret: str) -> bool:
        hashValue = self.__compute_hash(requestBody, signingSecret)
        return hashValue in self.signatures

    def __compute_hash(self, requestBody: str, signingSecret: str) -> str:
        data = str(self.request_timestamp) + "." + requestBody
        return hmac.new(
            bytes(signingSecret, "utf-8"),
            data.encode("utf-8"),
            digestmod=hashlib.sha256,
        ).hexdigest()

    def get_current_unix_time(self) -> int:
        return int(time.time())



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from freeclimb.models.sms_toll_free_campaign_registration_status import (
    SMSTollFreeCampaignRegistrationStatus,
)
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class TFNCampaign(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    TFNCampaign
    """  # noqa: E501

    account_id: Optional[StrictStr] = Field(
        description="ID of the account that created this participant.",
        alias="accountId",
    )
    campaign_id: Annotated[str, Field(strict=True)] = Field(
        description="TFNCampaignId", alias="campaignId"
    )
    use_case: StrictStr = Field(alias="useCase")
    registration_status: SMSTollFreeCampaignRegistrationStatus = Field(
        alias="registrationStatus"
    )
    date_created: StrictStr = Field(alias="dateCreated")
    date_updated: StrictStr = Field(alias="dateUpdated")
    date_created_iso: StrictStr = Field(alias="dateCreatedISO")
    date_updated_iso: StrictStr = Field(alias="dateUpdatedISO")
    revision: StrictInt

    __properties: ClassVar[List[str]] = [
        "accountId",
        "campaignId",
        "useCase",
        "registrationStatus",
        "dateCreated",
        "dateUpdated",
        "dateCreatedISO",
        "dateUpdatedISO",
        "revision",
    ]

    @field_validator("campaign_id")
    def campaign_id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"cmptfn_[a-fA-F0-9]{40}", value):
            raise ValueError(
                r"must validate the regular expression /cmptfn_[a-fA-F0-9]{40}/"
            )
        return value

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TFNCampaign from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TFNCampaign from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accountId": obj.get("accountId"),
                "campaignId": obj.get("campaignId"),
                "useCase": obj.get("useCase"),
                "registrationStatus": obj.get("registrationStatus"),
                "dateCreated": obj.get("dateCreated"),
                "dateUpdated": obj.get("dateUpdated"),
                "dateCreatedISO": obj.get("dateCreatedISO"),
                "dateUpdatedISO": obj.get("dateUpdatedISO"),
                "revision": obj.get("revision"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class MakeCallRequest(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    MakeCallRequest
    """  # noqa: E501

    var_from: StrictStr = Field(
        description="Phone number to use as the caller ID. This can be: (a) The To or From number provided in FreeClimb's initial request to your app or (b) Any incoming phone number you have purchased from FreeClimb.",
        alias="from",
    )
    to: StrictStr = Field(description="Phone number to place the Call to.")
    application_id: Optional[StrictStr] = Field(
        default=None,
        description="Required if no `parentCallId` or `callConnectUrl` has been provided. ID of the application FreeClimb should use to handle this phone call. FreeClimb will use the `callConnectUrl` and `statusCallbackUrl` set on the application unless the `callConnectUrl` attribute is also provided with the request. In this case, the URL specified in that `callConnectUrl` attribute will be used as a replacement of the `callConnectUrl` originally assigned in the application. If the `callConnectUrl` is not set as either an attribute of the request or as part of the specified application, an error will be provided. The application’s voiceUrl parameter is not used for outbound calls.",
        alias="applicationId",
    )
    send_digits: Optional[StrictStr] = Field(
        default=None,
        description="String of digits to dial after connecting to the number. It can include digits `0-9`, `*`, and `#`, and allows embedding a pause between the output of individual digits. The default pause is 500 milliseconds. So, a string such as *1234#* will be played in 2 seconds because of the 4 standard pauses implied within the string. A custom pause is specified by including a positive integer wrapped in curly braces: {n}. For more information, see **sendDigits examples** below.",
        alias="sendDigits",
    )
    if_machine: Optional[StrictStr] = Field(
        default=None,
        description="Specifies how FreeClimb should handle this Call if an answering machine answers it.",
        alias="ifMachine",
    )
    if_machine_url: Optional[StrictStr] = Field(
        default=None,
        description="This attribute specifies a URL to which FreeClimb will make a POST request when an answering machine or a fax machine is detected. This URL is required if the ifMachine flag is set to redirect. When ifMachine is set to hangup, ifMachineUrl must not be included in the request. For more information, see **ifMachineUrl example** below.",
        alias="ifMachineUrl",
    )
    timeout: Optional[StrictInt] = Field(
        default=30,
        description="Number of seconds that FreeClimb should allow the phone to ring before assuming there is no answer. Default is 30 seconds. Maximum allowed ring-time is determined by the target phone's provider. Note that most providers limit ring-time to 120 seconds.",
    )
    parent_call_id: Optional[StrictStr] = Field(
        default=None,
        description="Required if no `applicationId` or `callConnectUrl` has been provided. The ID of the parent Call in the case that this new Call is meant to be treated as a child of an existing Call. This attribute should be included when possible to reduce latency when adding child calls to Conferences containing the parent Call. A call can only be used as a parent once the call is in progress or as an inbound call that is still ringing. An outbound call is considered to be in progress once the `outdialConnect` or `outdialApiConnect` webhook is invoked. An inbound call is ringing when the inbound webhook is invoked. If a `callConnectUrl` attribute is also included with the `parentCallId` in the request, this URL will be used as a replacement of the `callConnectUrl` originally assigned in the parent call.",
        alias="parentCallId",
    )
    privacy_mode: Optional[StrictBool] = Field(
        default=None,
        description="Activate privacy mode in order to obscure log data that can potentially expose private information.",
        alias="privacyMode",
    )
    call_connect_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL that FreeClimb should use to handle this phone call. If an applicationId or parentCallId have already been provided, this callConnectUrl attribute will be used as a replacement of the callConnectUrl originally assigned in the application or parent call.",
        alias="callConnectUrl",
    )

    __properties: ClassVar[List[str]] = [
        "from",
        "to",
        "applicationId",
        "sendDigits",
        "ifMachine",
        "ifMachineUrl",
        "timeout",
        "parentCallId",
        "privacyMode",
        "callConnectUrl",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MakeCallRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MakeCallRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "from": obj.get("from"),
                "to": obj.get("to"),
                "applicationId": obj.get("applicationId"),
                "sendDigits": obj.get("sendDigits"),
                "ifMachine": obj.get("ifMachine"),
                "ifMachineUrl": obj.get("ifMachineUrl"),
                "timeout": obj.get("timeout") if obj.get("timeout") is not None else 30,
                "parentCallId": obj.get("parentCallId"),
                "privacyMode": obj.get("privacyMode"),
                "callConnectUrl": obj.get("callConnectUrl"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.account_result import AccountResult


class TestAccountResult(unittest.TestCase):
    """AccountResult unit test stubs"""

    def setUp(self):
        self.model = AccountResult()

    def test_uri(self):
        """Test AccountResult.uri"""

        self.model.uri = "TEST_STRING"
        assert self.model.uri == "TEST_STRING"

    def test_date_created(self):
        """Test AccountResult.date_created"""

        self.model.date_created = "TEST_STRING"
        assert self.model.date_created == "TEST_STRING"

    def test_date_updated(self):
        """Test AccountResult.date_updated"""

        self.model.date_updated = "TEST_STRING"
        assert self.model.date_updated == "TEST_STRING"

    def test_revision(self):
        """Test AccountResult.revision"""
        self.model.revision = 1
        assert self.model.revision == 1

    def test_account_id(self):
        """Test AccountResult.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_api_key(self):
        """Test AccountResult.api_key"""

        self.model.api_key = "TEST_STRING"
        assert self.model.api_key == "TEST_STRING"

    def test_alias(self):
        """Test AccountResult.alias"""

        self.model.alias = "TEST_STRING"
        assert self.model.alias == "TEST_STRING"

    def test_label(self):
        """Test AccountResult.label"""

        self.model.label = "TEST_STRING"
        assert self.model.label == "TEST_STRING"

    def test_type(self):
        """Test AccountResult.type"""
        self.model.type = AccountType.TRIAL
        assert self.model.type == AccountType.TRIAL
        self.model.type = AccountType.FULL
        assert self.model.type == AccountType.FULL

    def test_status(self):
        """Test AccountResult.status"""
        self.model.status = AccountStatus.CLOSED
        assert self.model.status == AccountStatus.CLOSED
        self.model.status = AccountStatus.SUSPENDED
        assert self.model.status == AccountStatus.SUSPENDED
        self.model.status = AccountStatus.ACTIVE
        assert self.model.status == AccountStatus.ACTIVE

    def test_subresource_uris(self):
        """Test AccountResult.subresource_uris"""
        object = None
        self.model.subresource_uris = object
        assert self.model.subresource_uris == object


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class ApplicationRequest(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    ApplicationRequest
    """  # noqa: E501

    alias: Optional[StrictStr] = Field(
        default=None,
        description="A human readable description of the application, with maximum length 64 characters.",
    )
    voice_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL that FreeClimb will request when an inbound call arrives on a phone number assigned to this application. Used only for inbound calls.",
        alias="voiceUrl",
    )
    voice_fallback_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL that FreeClimb will request if it times out waiting for a response from the voiceUrl. Used for inbound calls only. Note: A PerCL response is expected to control the inbound call.",
        alias="voiceFallbackUrl",
    )
    call_connect_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL that FreeClimb will request when an outbound call request is complete. Used for outbound calls only.  Note: A PerCL response is expected if the outbound call is connected (status=InProgress) to control the call.",
        alias="callConnectUrl",
    )
    status_callback_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL that FreeClimb will request to pass call status (such as call ended) to the application.  Note: This is a notification only; any PerCL returned will be ignored.",
        alias="statusCallbackUrl",
    )
    sms_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL that FreeClimb will request when a phone number assigned to this application receives an incoming SMS message. Used for inbound SMS only.  Note: Any PerCL returned will be ignored.",
        alias="smsUrl",
    )
    sms_fallback_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL that FreeClimb will request if it times out waiting for a response from the smsUrl. Used for inbound SMS only.  Note: Any PerCL returned will be ignored.",
        alias="smsFallbackUrl",
    )

    __properties: ClassVar[List[str]] = [
        "alias",
        "voiceUrl",
        "voiceFallbackUrl",
        "callConnectUrl",
        "statusCallbackUrl",
        "smsUrl",
        "smsFallbackUrl",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApplicationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if voice_url (nullable) is None
        # and model_fields_set contains the field
        if self.voice_url is None and "voice_url" in self.model_fields_set:
            _dict["voiceUrl"] = None

        # set to None if voice_fallback_url (nullable) is None
        # and model_fields_set contains the field
        if (
            self.voice_fallback_url is None
            and "voice_fallback_url" in self.model_fields_set
        ):
            _dict["voiceFallbackUrl"] = None

        # set to None if call_connect_url (nullable) is None
        # and model_fields_set contains the field
        if (
            self.call_connect_url is None
            and "call_connect_url" in self.model_fields_set
        ):
            _dict["callConnectUrl"] = None

        # set to None if status_callback_url (nullable) is None
        # and model_fields_set contains the field
        if (
            self.status_callback_url is None
            and "status_callback_url" in self.model_fields_set
        ):
            _dict["statusCallbackUrl"] = None

        # set to None if sms_url (nullable) is None
        # and model_fields_set contains the field
        if self.sms_url is None and "sms_url" in self.model_fields_set:
            _dict["smsUrl"] = None

        # set to None if sms_fallback_url (nullable) is None
        # and model_fields_set contains the field
        if (
            self.sms_fallback_url is None
            and "sms_fallback_url" in self.model_fields_set
        ):
            _dict["smsFallbackUrl"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApplicationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "alias": obj.get("alias"),
                "voiceUrl": obj.get("voiceUrl"),
                "voiceFallbackUrl": obj.get("voiceFallbackUrl"),
                "callConnectUrl": obj.get("callConnectUrl"),
                "statusCallbackUrl": obj.get("statusCallbackUrl"),
                "smsUrl": obj.get("smsUrl"),
                "smsFallbackUrl": obj.get("smsFallbackUrl"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.add_to_conference import AddToConference


class TestAddToConference(unittest.TestCase):
    """AddToConference unit test stubs"""

    def setUp(self):
        self.model = AddToConference(
            conference_id="TS",
        )

    def test_allow_call_control(self):
        """Test AddToConference.allow_call_control"""
        self.model.allow_call_control = False
        assert self.model.allow_call_control == False

    def test_call_control_sequence(self):
        """Test AddToConference.call_control_sequence"""

        self.model.call_control_sequence = "TEST_STRING"
        assert self.model.call_control_sequence == "TEST_STRING"

    def test_call_control_url(self):
        """Test AddToConference.call_control_url"""
        self.model.call_control_url = "TEST_STRING"
        assert self.model.call_control_url == "TEST_STRING"

    def test_conference_id(self):
        """Test AddToConference.conference_id"""

        self.model.conference_id = "TEST_STRING"
        assert self.model.conference_id == "TEST_STRING"

    def test_leave_conference_url(self):
        """Test AddToConference.leave_conference_url"""
        self.model.leave_conference_url = "TEST_STRING"
        assert self.model.leave_conference_url == "TEST_STRING"

    def test_listen(self):
        """Test AddToConference.listen"""
        self.model.listen = False
        assert self.model.listen == False

    def test_notification_url(self):
        """Test AddToConference.notification_url"""
        self.model.notification_url = "TEST_STRING"
        assert self.model.notification_url == "TEST_STRING"

    def test_start_conf_on_enter(self):
        """Test AddToConference.start_conf_on_enter"""
        self.model.start_conf_on_enter = False
        assert self.model.start_conf_on_enter == False

    def test_talk(self):
        """Test AddToConference.talk"""
        self.model.talk = False
        assert self.model.talk == False

    def test_dtmf_pass_through(self):
        """Test AddToConference.dtmf_pass_through"""
        self.model.dtmf_pass_through = False
        assert self.model.dtmf_pass_through == False


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class QueueResult(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    QueueResult
    """  # noqa: E501

    uri: Optional[StrictStr] = Field(
        default=None, description="The URI for this resource, relative to /apiserver."
    )
    date_created: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateCreated",
    )
    date_updated: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateUpdated",
    )
    revision: Optional[StrictInt] = Field(
        default=None,
        description="Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the account that created this Queue.",
        alias="accountId",
    )
    queue_id: Optional[StrictStr] = Field(
        default=None,
        description="A string that uniquely identifies this Queue resource.",
        alias="queueId",
    )
    alias: Optional[StrictStr] = Field(
        default=None, description="A description for this Queue."
    )
    max_size: Optional[StrictInt] = Field(
        default=None,
        description="The maximum number of Calls permitted in the Queue. Default is 100. Maximum is 1000.",
        alias="maxSize",
    )
    current_size: Optional[StrictInt] = Field(
        default=None,
        description="Count of Calls currently in the Queue.",
        alias="currentSize",
    )
    average_queue_removal_time: Optional[StrictInt] = Field(
        default=None,
        description="The average amount of time (in seconds) for a call to be removed from the queue.",
        alias="averageQueueRemovalTime",
    )
    subresource_uris: Optional[Dict[str, Any]] = Field(
        default=None,
        description="List of subresources for this Queue (which includes Queue members).",
        alias="subresourceUris",
    )

    __properties: ClassVar[List[str]] = [
        "uri",
        "dateCreated",
        "dateUpdated",
        "revision",
        "accountId",
        "queueId",
        "alias",
        "maxSize",
        "currentSize",
        "averageQueueRemovalTime",
        "subresourceUris",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of QueueResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        # set to None if queue_id (nullable) is None
        # and model_fields_set contains the field
        if self.queue_id is None and "queue_id" in self.model_fields_set:
            _dict["queueId"] = None

        # set to None if alias (nullable) is None
        # and model_fields_set contains the field
        if self.alias is None and "alias" in self.model_fields_set:
            _dict["alias"] = None

        # set to None if max_size (nullable) is None
        # and model_fields_set contains the field
        if self.max_size is None and "max_size" in self.model_fields_set:
            _dict["maxSize"] = None

        # set to None if current_size (nullable) is None
        # and model_fields_set contains the field
        if self.current_size is None and "current_size" in self.model_fields_set:
            _dict["currentSize"] = None

        # set to None if average_queue_removal_time (nullable) is None
        # and model_fields_set contains the field
        if (
            self.average_queue_removal_time is None
            and "average_queue_removal_time" in self.model_fields_set
        ):
            _dict["averageQueueRemovalTime"] = None

        # set to None if subresource_uris (nullable) is None
        # and model_fields_set contains the field
        if (
            self.subresource_uris is None
            and "subresource_uris" in self.model_fields_set
        ):
            _dict["subresourceUris"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of QueueResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "uri": obj.get("uri"),
                "dateCreated": obj.get("dateCreated"),
                "dateUpdated": obj.get("dateUpdated"),
                "revision": obj.get("revision"),
                "accountId": obj.get("accountId"),
                "queueId": obj.get("queueId"),
                "alias": obj.get("alias"),
                "maxSize": obj.get("maxSize"),
                "currentSize": obj.get("currentSize"),
                "averageQueueRemovalTime": obj.get("averageQueueRemovalTime"),
                "subresourceUris": obj.get("subresourceUris"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.message_status_webhook import MessageStatusWebhook


class TestMessageStatusWebhook(unittest.TestCase):
    """MessageStatusWebhook unit test stubs"""

    def setUp(self):
        self.model = MessageStatusWebhook()

    def test_request_type(self):
        """Test MessageStatusWebhook.request_type"""

    def test_account_id(self):
        """Test MessageStatusWebhook.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_message_id(self):
        """Test MessageStatusWebhook.message_id"""

        self.model.message_id = "TEST_STRING"
        assert self.model.message_id == "TEST_STRING"

    def test_call_id(self):
        """Test MessageStatusWebhook.call_id"""

        self.model.call_id = "TEST_STRING"
        assert self.model.call_id == "TEST_STRING"

    def test_var_from(self):
        """Test MessageStatusWebhook.var_from"""

        self.model.var_from = "TEST_STRING"
        assert self.model.var_from == "TEST_STRING"

    def test_to(self):
        """Test MessageStatusWebhook.to"""

        self.model.to = "TEST_STRING"
        assert self.model.to == "TEST_STRING"

    def test_text(self):
        """Test MessageStatusWebhook.text"""

        self.model.text = "TEST_STRING"
        assert self.model.text == "TEST_STRING"

    def test_direction(self):
        """Test MessageStatusWebhook.direction"""

        self.model.direction = "TEST_STRING"
        assert self.model.direction == "TEST_STRING"

    def test_application_id(self):
        """Test MessageStatusWebhook.application_id"""

        self.model.application_id = "TEST_STRING"
        assert self.model.application_id == "TEST_STRING"

    def test_status(self):
        """Test MessageStatusWebhook.status"""
        self.model.status = MessageStatus.NEW
        assert self.model.status == MessageStatus.NEW
        self.model.status = MessageStatus.QUEUED
        assert self.model.status == MessageStatus.QUEUED
        self.model.status = MessageStatus.REJECTED
        assert self.model.status == MessageStatus.REJECTED
        self.model.status = MessageStatus.SENDING
        assert self.model.status == MessageStatus.SENDING
        self.model.status = MessageStatus.SENT
        assert self.model.status == MessageStatus.SENT
        self.model.status = MessageStatus.FAILED
        assert self.model.status == MessageStatus.FAILED
        self.model.status = MessageStatus.RECEIVED
        assert self.model.status == MessageStatus.RECEIVED
        self.model.status = MessageStatus.UNDELIVERED
        assert self.model.status == MessageStatus.UNDELIVERED
        self.model.status = MessageStatus.EXPIRED
        assert self.model.status == MessageStatus.EXPIRED
        self.model.status = MessageStatus.DELETED
        assert self.model.status == MessageStatus.DELETED
        self.model.status = MessageStatus.UNKNOWN
        assert self.model.status == MessageStatus.UNKNOWN

    def test_phone_number_id(self):
        """Test MessageStatusWebhook.phone_number_id"""

        self.model.phone_number_id = "TEST_STRING"
        assert self.model.phone_number_id == "TEST_STRING"

    def test_deserialize(self):
        payload = '{ "requestType": "messageStatus" }'
        assert isinstance(
            MessageStatusWebhook.deserialize(payload), MessageStatusWebhook
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.get_digits import GetDigits


class TestGetDigits(unittest.TestCase):
    """GetDigits unit test stubs"""

    def setUp(self):
        self.model = GetDigits(
            action_url="TS",
        )

    def test_action_url(self):
        """Test GetDigits.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.action_url == "TEST_STRING"

    def test_digit_timeout_ms(self):
        """Test GetDigits.digit_timeout_ms"""
        self.model.digit_timeout_ms = 1
        assert self.model.digit_timeout_ms == 1

    def test_finish_on_key(self):
        """Test GetDigits.finish_on_key"""

        self.model.finish_on_key = "TEST_STRING"
        assert self.model.finish_on_key == "TEST_STRING"

    def test_flush_buffer(self):
        """Test GetDigits.flush_buffer"""
        self.model.flush_buffer = False
        assert self.model.flush_buffer == False

    def test_initial_timeout_ms(self):
        """Test GetDigits.initial_timeout_ms"""
        self.model.initial_timeout_ms = 1
        assert self.model.initial_timeout_ms == 1

    def test_max_digits(self):
        """Test GetDigits.max_digits"""
        self.model.max_digits = 1
        assert self.model.max_digits == 1

    def test_min_digits(self):
        """Test GetDigits.min_digits"""
        self.model.min_digits = 1
        assert self.model.min_digits == 1

    def test_prompts(self):
        """Test GetDigits.prompts"""
        testList = []
        self.model.prompts = testList
        assert self.model.prompts == testList

    def test_privacy_mode(self):
        """Test GetDigits.privacy_mode"""
        self.model.privacy_mode = False
        assert self.model.privacy_mode == False


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.message_result import MessageResult


class TestMessageResult(unittest.TestCase):
    """MessageResult unit test stubs"""

    def setUp(self):
        self.model = MessageResult()

    def test_uri(self):
        """Test MessageResult.uri"""

        self.model.uri = "TEST_STRING"
        assert self.model.uri == "TEST_STRING"

    def test_date_created(self):
        """Test MessageResult.date_created"""

        self.model.date_created = "TEST_STRING"
        assert self.model.date_created == "TEST_STRING"

    def test_date_updated(self):
        """Test MessageResult.date_updated"""

        self.model.date_updated = "TEST_STRING"
        assert self.model.date_updated == "TEST_STRING"

    def test_revision(self):
        """Test MessageResult.revision"""
        self.model.revision = 1
        assert self.model.revision == 1

    def test_account_id(self):
        """Test MessageResult.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_message_id(self):
        """Test MessageResult.message_id"""

        self.model.message_id = "TEST_STRING"
        assert self.model.message_id == "TEST_STRING"

    def test_status(self):
        """Test MessageResult.status"""
        self.model.status = MessageStatus.NEW
        assert self.model.status == MessageStatus.NEW
        self.model.status = MessageStatus.QUEUED
        assert self.model.status == MessageStatus.QUEUED
        self.model.status = MessageStatus.REJECTED
        assert self.model.status == MessageStatus.REJECTED
        self.model.status = MessageStatus.SENDING
        assert self.model.status == MessageStatus.SENDING
        self.model.status = MessageStatus.SENT
        assert self.model.status == MessageStatus.SENT
        self.model.status = MessageStatus.FAILED
        assert self.model.status == MessageStatus.FAILED
        self.model.status = MessageStatus.RECEIVED
        assert self.model.status == MessageStatus.RECEIVED
        self.model.status = MessageStatus.UNDELIVERED
        assert self.model.status == MessageStatus.UNDELIVERED
        self.model.status = MessageStatus.EXPIRED
        assert self.model.status == MessageStatus.EXPIRED
        self.model.status = MessageStatus.DELETED
        assert self.model.status == MessageStatus.DELETED
        self.model.status = MessageStatus.UNKNOWN
        assert self.model.status == MessageStatus.UNKNOWN

    def test_var_from(self):
        """Test MessageResult.var_from"""

        self.model.var_from = "TEST_STRING"
        assert self.model.var_from == "TEST_STRING"

    def test_to(self):
        """Test MessageResult.to"""

        self.model.to = "TEST_STRING"
        assert self.model.to == "TEST_STRING"

    def test_text(self):
        """Test MessageResult.text"""

        self.model.text = "TEST_STRING"
        assert self.model.text == "TEST_STRING"

    def test_direction(self):
        """Test MessageResult.direction"""

        self.model.direction = "TEST_STRING"
        assert self.model.direction == "TEST_STRING"

    def test_notification_url(self):
        """Test MessageResult.notification_url"""
        self.model.notification_url = "TEST_STRING"
        assert self.model.notification_url == "TEST_STRING"

    def test_brand_id(self):
        """Test MessageResult.brand_id"""

        self.model.brand_id = "TEST_STRING"
        assert self.model.brand_id == "TEST_STRING"

    def test_campaign_id(self):
        """Test MessageResult.campaign_id"""

        self.model.campaign_id = "TEST_STRING"
        assert self.model.campaign_id == "TEST_STRING"

    def test_segment_count(self):
        """Test MessageResult.segment_count"""

        self.model.segment_count = float(1)
        assert self.model.segment_count == float(1)

    def test_media_urls(self):
        """Test MessageResult.media_urls"""
        testList = []
        self.model.media_urls = testList
        assert self.model.media_urls == testList

    def test_tfn(self):
        """Test MessageResult.tfn"""
        object = freeclimb.models.tfn.TFN(
            campaign_id="",
        )
        self.model.tfn = object
        assert self.model.tfn == object

    def test_phone_number_id(self):
        """Test MessageResult.phone_number_id"""

        self.model.phone_number_id = "TEST_STRING"
        assert self.model.phone_number_id == "TEST_STRING"

    def test_application_id(self):
        """Test MessageResult.application_id"""

        self.model.application_id = "TEST_STRING"
        assert self.model.application_id == "TEST_STRING"


if __name__ == "__main__":
    unittest.main()



import sys

from freeclimb.utils.signature_information import SignatureInformation


class RequestVerifier:

    DEFAULT_TOLERANCE = 5 * 60 * 1000

    @staticmethod
    def verify_request_signature(
        request_body: str,
        request_header: str,
        signing_secret: str,
        tolerance: int = DEFAULT_TOLERANCE,
    ):
        verifier = RequestVerifier()
        verifier.__check_request_body(request_body)
        verifier.__check_request_header(request_header)
        verifier.__check_signing_secret(signing_secret)
        verifier.__check_tolerance(tolerance)
        info = SignatureInformation(request_header)
        verifier.__verify_tolerance(info, tolerance)
        verifier.__verify_signature(info, request_body, signing_secret)

    def __check_request_body(self, request_body: str):
        if request_body == "" or request_body == None:
            raise Exception("Request Body cannot be empty or null")

    def __check_request_header(self, request_header: str):
        if request_header == "" or request_header == None:
            raise Exception("Error with request header, Request header is empty")

        elif not ("t" in request_header):
            raise Exception("Error with request header, timestamp is not present")

        elif not ("v1" in request_header):
            raise Exception("Error with request header, signatures are not present")

    def __check_signing_secret(self, signing_secret: str):
        if signing_secret == "" or signing_secret == None:
            raise Exception("Signing secret cannot be empty or null")

    def __check_tolerance(self, tolerance: int):
        if tolerance <= 0 or tolerance >= sys.maxsize:
            raise Exception("Tolerance value must be a positive integer")

    def __verify_tolerance(self, info: SignatureInformation, tolerance: int):
        currentTime = info.get_current_unix_time()
        if not (info.is_request_time_valid(tolerance)):
            raise Exception(
                "Request time exceeded tolerance threshold. Request: "
                + str(info.request_timestamp)
                + ", CurrentTime: "
                + str(currentTime)
                + ", tolerance: "
                + str(tolerance)
            )

    def __verify_signature(
        self, info: SignatureInformation, request_body: str, signing_secret: str
    ):
        if not (info.is_signature_safe(request_body, signing_secret)):
            raise Exception(
                "Unverified signature request, If this request was unexpected, it may be from a bad actor. Please proceed with caution. If the request was exepected, please check any typos or issues with the signingSecret"
            )



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.if_machine import IfMachine
from freeclimb.models.percl_command import PerclCommand
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class OutDial(
    PerclCommand,
    populate_by_name=True,
    validate_assignment=True,
    protected_namespaces=(),
):
    """
    The OutDial command is used to call a phone number
    """  # noqa: E501

    action_url: StrictStr = Field(
        description="URL to which FreeClimb sends an HTTP POST request. ",
        alias="actionUrl",
    )
    call_connect_url: StrictStr = Field(
        description="URL to which FreeClimb makes an HTTP POST request informing the result of the OutDial.",
        alias="callConnectUrl",
    )
    calling_number: StrictStr = Field(
        description="he caller ID to show to the called party when FreeClimb calls. This can be one of the following: The To or From number provided in the first Webhook to your webserver. Any phone number you have purchased from FreeClimb.",
        alias="callingNumber",
    )
    destination: StrictStr = Field(
        description="E.164 representation of the phone number to Call. "
    )
    if_machine: Optional[IfMachine] = Field(default=None, alias="ifMachine")
    if_machine_url: Optional[StrictStr] = Field(
        default=None,
        description="When the `ifMachine` flag is set to `redirect`, this attribute specifies a URL to which FreeClimb makes a POST request when an answering machine or a fax machine is detected. This URL is required if the `ifMachine` flag is set to `redirect`. Otherwise, it should not be included.",
        alias="ifMachineUrl",
    )
    send_digits: Optional[StrictStr] = Field(
        default=None,
        description="DTMF tones to play to the outdialed Call. This is typically used to dial a number and then dial an extension.",
        alias="sendDigits",
    )
    status_callback_url: Optional[StrictStr] = Field(
        default=None,
        description="When the outdialed Call leg terminates, FreeClimb sends a `callStatus` Webhook to the `statusCallbackUrl`. This is a notification only; any PerCL command returned is ignored.",
        alias="statusCallbackUrl",
    )
    timeout: Optional[StrictInt] = Field(
        default=None,
        description="Maximum time in seconds the `OutDial` command waits for the called party to answer the Call. When a timeout occurs, FreeClimb invokes the `callConnectUrl` Webhook to report that the out-dialed Call has ended with a status of `noAnswer`.",
    )
    privacy_mode: Optional[StrictBool] = Field(
        default=None,
        description="Parameter `privacyMode` will not log the `text` as required by PCI compliance.",
        alias="privacyMode",
    )
    command: StrictStr = "OutDial"

    __properties: ClassVar[List[str]] = [
        "command",
        "actionUrl",
        "callConnectUrl",
        "callingNumber",
        "destination",
        "ifMachine",
        "ifMachineUrl",
        "sendDigits",
        "statusCallbackUrl",
        "timeout",
        "privacyMode",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OutDial from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OutDial from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "command": obj.get("command"),
                "actionUrl": obj.get("actionUrl"),
                "callConnectUrl": obj.get("callConnectUrl"),
                "callingNumber": obj.get("callingNumber"),
                "destination": obj.get("destination"),
                "ifMachine": obj.get("ifMachine"),
                "ifMachineUrl": obj.get("ifMachineUrl"),
                "sendDigits": obj.get("sendDigits"),
                "statusCallbackUrl": obj.get("statusCallbackUrl"),
                "timeout": obj.get("timeout"),
                "privacyMode": obj.get("privacyMode"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.percl_command import PerclCommand
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class GetDigits(
    PerclCommand,
    populate_by_name=True,
    validate_assignment=True,
    protected_namespaces=(),
):
    """
    The `GetDigits` command collects DTMF inputs from the caller. It is only supported only when there is a single party on the Call. `GetDigits` is a Terminal Command — any actions following it are never executed. When the Caller is done entering the digits, FreeClimb submits that data to the provided `actionUrl` using an HTTP POST request. Your server will be required to respond to the FreeClimb Webhook with PerCL to continue handling the call.
    """  # noqa: E501

    action_url: StrictStr = Field(
        description="When the Caller has finished entering digits, FreeClimb will make an HTTP POST request to this URL. A PerCL response is expected to continue handling the Call. Make sure to keep “http://“ in the URL.",
        alias="actionUrl",
    )
    digit_timeout_ms: Optional[StrictInt] = Field(
        default=None,
        description=" Maximum time in milliseconds that FreeClimb will wait for the Caller to press any digit after the last digit entered, before making a determination that a `timeout` has occurred and moving on to make the request to the actionUrl to submit the results of the `GetDigits` command. This timeout interval begins and resets after each digit entered.",
        alias="digitTimeoutMs",
    )
    finish_on_key: Optional[StrictStr] = Field(
        default=None,
        description="Digit that causes the input sequence to be deemed complete. This attribute defers to the `timeout` attribute – so, if a `timeout` occurs, then the command terminates regardless of the value of `finishOnKey`.",
        alias="finishOnKey",
    )
    flush_buffer: Optional[StrictBool] = Field(
        default=None,
        description="If set to true, the FreeClimb platform starts with an empty DTMF buffer to store the digits entered by the caller. If set to false, FreeClimb will append the user inputs to the end of the existing digits buffer and will return digits from the start of the digits buffer.",
        alias="flushBuffer",
    )
    initial_timeout_ms: Optional[StrictInt] = Field(
        default=None,
        description="Maximum time in milliseconds that FreeClimb will wait for the Caller to press the first digit before making a determination that a `timeout` has occurred and moving on to make the request to the `actionUrl` to submit the results of the `GetDigits` command. This timeout interval begins when all nested commands have been fully executed.",
        alias="initialTimeoutMs",
    )
    max_digits: Optional[StrictInt] = Field(
        default=None,
        description="Maximum number of digits expected in the input. If the terminating digit is not entered and the caller has entered the maximum number of digits allowed, the `GetDigits` command terminates regardless of the value of `finishOnKey`.",
        alias="maxDigits",
    )
    min_digits: Optional[StrictInt] = Field(
        default=None,
        description="Minimum number of digits expected in the input. If specified, FreeClimb will return the collected digits only if the Caller has entered at least that many digits.",
        alias="minDigits",
    )
    prompts: Optional[List[PerclCommand]] = Field(
        default=None,
        description="JSON array of PerCL commands to nest within the `GetDigits` command. The `Say`, `Play`, and `Pause` commands can be used. The nested actions are executed while FreeClimb is waiting for input from the Caller.",
    )
    privacy_mode: Optional[StrictBool] = Field(
        default=None,
        description="Parameter `privacyMode` will not log the `text` as required by PCI compliance.",
        alias="privacyMode",
    )
    command: StrictStr = "GetDigits"

    __properties: ClassVar[List[str]] = [
        "command",
        "actionUrl",
        "digitTimeoutMs",
        "finishOnKey",
        "flushBuffer",
        "initialTimeoutMs",
        "maxDigits",
        "minDigits",
        "prompts",
        "privacyMode",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetDigits from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in prompts (list)
        _items = []
        if self.prompts:
            for _item_prompts in self.prompts:
                if _item_prompts:
                    _items.append(_item_prompts.to_dict())
            _dict["prompts"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetDigits from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "command": obj.get("command"),
                "actionUrl": obj.get("actionUrl"),
                "digitTimeoutMs": obj.get("digitTimeoutMs"),
                "finishOnKey": obj.get("finishOnKey"),
                "flushBuffer": obj.get("flushBuffer"),
                "initialTimeoutMs": obj.get("initialTimeoutMs"),
                "maxDigits": obj.get("maxDigits"),
                "minDigits": obj.get("minDigits"),
                "prompts": (
                    [PerclCommand.from_dict(_item) for _item in obj["prompts"]]
                    if obj.get("prompts") is not None
                    else None
                ),
                "privacyMode": obj.get("privacyMode"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.percl_command import PerclCommand
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class Enqueue(
    PerclCommand,
    populate_by_name=True,
    validate_assignment=True,
    protected_namespaces=(),
):
    """
    The `Enqueue` command adds the current Call to a call Queue. If the specified Queue does not exist, it is created and then the Call is added to it. The default maximum length of the queue is 100. This can be modified using the REST API.
    """  # noqa: E501

    action_url: StrictStr = Field(
        description="A request is made to this URL when the Call leaves the Queue, which can occur if enqueue of the Call fails or when the call is dequeued via the `Dequeue` command, the REST API (POST to Queue Member resource), or the caller hangs up.",
        alias="actionUrl",
    )
    notification_url: Optional[StrictStr] = Field(
        default=None,
        description="URL to be invoked when the call enters the queue. The request to the URL contains the standard request parameters.This is a notification only; any PerCL returned will be ignored.",
        alias="notificationUrl",
    )
    queue_id: StrictStr = Field(
        description="ID of the Queue to which to add the Call. If the Queue does not exist, it will be created. The ID must start with QU followed by 40 hex characters.",
        alias="queueId",
    )
    wait_url: StrictStr = Field(
        description="A request is made to this URL when the Call leaves the Queue, which can occur if enqueue of the Call fails or when the call is dequeued via the `Dequeue` command, the REST API (POST to Queue Member resource), or the caller hangs up.",
        alias="waitUrl",
    )
    command: StrictStr = "Enqueue"

    __properties: ClassVar[List[str]] = [
        "command",
        "actionUrl",
        "notificationUrl",
        "queueId",
        "waitUrl",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Enqueue from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Enqueue from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "command": obj.get("command"),
                "actionUrl": obj.get("actionUrl"),
                "notificationUrl": obj.get("notificationUrl"),
                "queueId": obj.get("queueId"),
                "waitUrl": obj.get("waitUrl"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.transcribe_webhook import TranscribeWebhook


class TestTranscribeWebhook(unittest.TestCase):
    """TranscribeWebhook unit test stubs"""

    def setUp(self):
        self.model = TranscribeWebhook()

    def test_request_type(self):
        """Test TranscribeWebhook.request_type"""

    def test_account_id(self):
        """Test TranscribeWebhook.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_call_id(self):
        """Test TranscribeWebhook.call_id"""

        self.model.call_id = "TEST_STRING"
        assert self.model.call_id == "TEST_STRING"

    def test_var_from(self):
        """Test TranscribeWebhook.var_from"""

        self.model.var_from = "TEST_STRING"
        assert self.model.var_from == "TEST_STRING"

    def test_to(self):
        """Test TranscribeWebhook.to"""

        self.model.to = "TEST_STRING"
        assert self.model.to == "TEST_STRING"

    def test_recording_id(self):
        """Test TranscribeWebhook.recording_id"""

        self.model.recording_id = "TEST_STRING"
        assert self.model.recording_id == "TEST_STRING"

    def test_recording_url(self):
        """Test TranscribeWebhook.recording_url"""
        self.model.recording_url = "TEST_STRING"
        assert self.model.recording_url == "TEST_STRING"

    def test_recording_size(self):
        """Test TranscribeWebhook.recording_size"""
        self.model.recording_size = 1
        assert self.model.recording_size == 1

    def test_recording_format(self):
        """Test TranscribeWebhook.recording_format"""

        self.model.recording_format = "TEST_STRING"
        assert self.model.recording_format == "TEST_STRING"

    def test_recording_duration_ms(self):
        """Test TranscribeWebhook.recording_duration_ms"""
        self.model.recording_duration_ms = 1
        assert self.model.recording_duration_ms == 1

    def test_term_reason(self):
        """Test TranscribeWebhook.term_reason"""
        self.model.term_reason = TranscribeTermReason.ERROR
        assert self.model.term_reason == TranscribeTermReason.ERROR
        self.model.term_reason = TranscribeTermReason.COMPLETED
        assert self.model.term_reason == TranscribeTermReason.COMPLETED

    def test_record_term_reason(self):
        """Test TranscribeWebhook.record_term_reason"""
        self.model.record_term_reason = RecordUtteranceTermReason.FINISH_KEY
        assert self.model.record_term_reason == RecordUtteranceTermReason.FINISH_KEY
        self.model.record_term_reason = RecordUtteranceTermReason.TIMEOUT
        assert self.model.record_term_reason == RecordUtteranceTermReason.TIMEOUT
        self.model.record_term_reason = RecordUtteranceTermReason.HANGUP
        assert self.model.record_term_reason == RecordUtteranceTermReason.HANGUP
        self.model.record_term_reason = RecordUtteranceTermReason.MAX_LENGTH
        assert self.model.record_term_reason == RecordUtteranceTermReason.MAX_LENGTH

    def test_digit(self):
        """Test TranscribeWebhook.digit"""

        self.model.digit = "TEST_STRING"
        assert self.model.digit == "TEST_STRING"

    def test_privacy_for_logging(self):
        """Test TranscribeWebhook.privacy_for_logging"""
        self.model.privacy_for_logging = False
        assert self.model.privacy_for_logging == False

    def test_privacy_for_recording(self):
        """Test TranscribeWebhook.privacy_for_recording"""
        self.model.privacy_for_recording = False
        assert self.model.privacy_for_recording == False

    def test_barge_in_reason(self):
        """Test TranscribeWebhook.barge_in_reason"""
        self.model.barge_in_reason = BargeInReason.NO_BARGE_IN
        assert self.model.barge_in_reason == BargeInReason.NO_BARGE_IN
        self.model.barge_in_reason = BargeInReason.BARGE_IN_BY_DTMF
        assert self.model.barge_in_reason == BargeInReason.BARGE_IN_BY_DTMF
        self.model.barge_in_reason = BargeInReason.BARGE_IN_BY_ENERGY
        assert self.model.barge_in_reason == BargeInReason.BARGE_IN_BY_ENERGY

    def test_barged_in_prompt_no(self):
        """Test TranscribeWebhook.barged_in_prompt_no"""
        self.model.barged_in_prompt_no = 1
        assert self.model.barged_in_prompt_no == 1

    def test_barged_in_prompt_ms(self):
        """Test TranscribeWebhook.barged_in_prompt_ms"""
        self.model.barged_in_prompt_ms = 1
        assert self.model.barged_in_prompt_ms == 1

    def test_barged_in_prompt_loop_no(self):
        """Test TranscribeWebhook.barged_in_prompt_loop_no"""
        self.model.barged_in_prompt_loop_no = 1
        assert self.model.barged_in_prompt_loop_no == 1

    def test_barge_in_time_ms(self):
        """Test TranscribeWebhook.barge_in_time_ms"""
        self.model.barge_in_time_ms = 1
        assert self.model.barge_in_time_ms == 1

    def test_transcript(self):
        """Test TranscribeWebhook.transcript"""

        self.model.transcript = "TEST_STRING"
        assert self.model.transcript == "TEST_STRING"

    def test_transcribe_reason(self):
        """Test TranscribeWebhook.transcribe_reason"""
        self.model.transcribe_reason = TranscribeReason.INTERNAL_ERROR
        assert self.model.transcribe_reason == TranscribeReason.INTERNAL_ERROR
        self.model.transcribe_reason = TranscribeReason.HANGUP
        assert self.model.transcribe_reason == TranscribeReason.HANGUP
        self.model.transcribe_reason = TranscribeReason.MAX_LENGTH
        assert self.model.transcribe_reason == TranscribeReason.MAX_LENGTH
        self.model.transcribe_reason = TranscribeReason.DIGIT
        assert self.model.transcribe_reason == TranscribeReason.DIGIT
        self.model.transcribe_reason = TranscribeReason.NO_INPUT
        assert self.model.transcribe_reason == TranscribeReason.NO_INPUT

    def test_transcription_duration_ms(self):
        """Test TranscribeWebhook.transcription_duration_ms"""
        self.model.transcription_duration_ms = 1
        assert self.model.transcription_duration_ms == 1

    def test_deserialize(self):
        payload = '{ "requestType": "transcribe" }'
        assert isinstance(TranscribeWebhook.deserialize(payload), TranscribeWebhook)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SMSTollFreeCampaignRegistrationStatus(str, Enum):
    """
    Current toll-free campaign registration status.Possible values: UNREGISTERED,INITIATED,PENDING,DECLINED,REGISTERED. A newly created campaign defaults to INITIATED status.
    """

    """
    allowed enum values
    """
    UNREGISTERED = "UNREGISTERED"
    INITIATED = "INITIATED"
    PENDING = "PENDING"
    DECLINED = "DECLINED"
    REGISTERED = "REGISTERED"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SMSTollFreeCampaignRegistrationStatus from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from freeclimb.models.percl_command import PerclCommand
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class PlayEarlyMedia(
    PerclCommand,
    populate_by_name=True,
    validate_assignment=True,
    protected_namespaces=(),
):
    """
    `PlayEarlyMedia` is relevant only when present as the very first command in the PerCL script returned for an incoming Call. In such cases, the command is executed before FreeClimb attempts to connect the call. The audio file it uses can be stored in any location that is accessible via URL.
    """  # noqa: E501

    file: StrictStr = Field(
        description="RL of the audio file to be played to the caller. The URL can be the `recordingUrl` generated from the `RecordUtterance` or `StartRecordCall` PerCL commands or any accessible URL. FreeClimb will respect Cache-Control headers for this file. Use these to limit repeated requests for unchanged audio. If no Cache-Control header is provided, the file will be cached for seven days by default."
    )
    command: StrictStr = "PlayEarlyMedia"

    __properties: ClassVar[List[str]] = ["command", "file"]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PlayEarlyMedia from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PlayEarlyMedia from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {"command": obj.get("command"), "file": obj.get("file")}
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.conference_status import ConferenceStatus
from freeclimb.models.play_beep import PlayBeep
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class ConferenceResult(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    ConferenceResult
    """  # noqa: E501

    uri: Optional[StrictStr] = Field(
        default=None, description="The URI for this resource, relative to /apiserver."
    )
    date_created: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateCreated",
    )
    date_updated: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateUpdated",
    )
    revision: Optional[StrictInt] = Field(
        default=None,
        description="Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.",
    )
    conference_id: Optional[StrictStr] = Field(
        default=None,
        description="A string that uniquely identifies this Conference resource.",
        alias="conferenceId",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the account that created this Conference.",
        alias="accountId",
    )
    alias: Optional[StrictStr] = Field(
        default=None, description="A description for this Conference."
    )
    play_beep: Optional[PlayBeep] = Field(default=None, alias="playBeep")
    record: Optional[StrictBool] = Field(
        default=None,
        description="Flag indicating whether recording is enabled for this Conference.",
    )
    status: Optional[ConferenceStatus] = None
    wait_url: Optional[StrictStr] = Field(
        default=None,
        description="URL referencing the audio file to be used as default wait music for the Conference when it is in the populated state.",
        alias="waitUrl",
    )
    action_url: Optional[StrictStr] = Field(
        default=None,
        description="URL invoked once the Conference is successfully created.",
        alias="actionUrl",
    )
    status_callback_url: Optional[StrictStr] = Field(
        default=None,
        description="URL to inform that the Conference status has changed.",
        alias="statusCallbackUrl",
    )
    subresource_uris: Optional[Dict[str, Any]] = Field(
        default=None,
        description="The list of subresources for this Conference. This includes participants and/or recordings.",
        alias="subresourceUris",
    )

    __properties: ClassVar[List[str]] = [
        "uri",
        "dateCreated",
        "dateUpdated",
        "revision",
        "conferenceId",
        "accountId",
        "alias",
        "playBeep",
        "record",
        "status",
        "waitUrl",
        "actionUrl",
        "statusCallbackUrl",
        "subresourceUris",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ConferenceResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if conference_id (nullable) is None
        # and model_fields_set contains the field
        if self.conference_id is None and "conference_id" in self.model_fields_set:
            _dict["conferenceId"] = None

        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        # set to None if alias (nullable) is None
        # and model_fields_set contains the field
        if self.alias is None and "alias" in self.model_fields_set:
            _dict["alias"] = None

        # set to None if play_beep (nullable) is None
        # and model_fields_set contains the field
        if self.play_beep is None and "play_beep" in self.model_fields_set:
            _dict["playBeep"] = None

        # set to None if record (nullable) is None
        # and model_fields_set contains the field
        if self.record is None and "record" in self.model_fields_set:
            _dict["record"] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict["status"] = None

        # set to None if wait_url (nullable) is None
        # and model_fields_set contains the field
        if self.wait_url is None and "wait_url" in self.model_fields_set:
            _dict["waitUrl"] = None

        # set to None if action_url (nullable) is None
        # and model_fields_set contains the field
        if self.action_url is None and "action_url" in self.model_fields_set:
            _dict["actionUrl"] = None

        # set to None if status_callback_url (nullable) is None
        # and model_fields_set contains the field
        if (
            self.status_callback_url is None
            and "status_callback_url" in self.model_fields_set
        ):
            _dict["statusCallbackUrl"] = None

        # set to None if subresource_uris (nullable) is None
        # and model_fields_set contains the field
        if (
            self.subresource_uris is None
            and "subresource_uris" in self.model_fields_set
        ):
            _dict["subresourceUris"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ConferenceResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "uri": obj.get("uri"),
                "dateCreated": obj.get("dateCreated"),
                "dateUpdated": obj.get("dateUpdated"),
                "revision": obj.get("revision"),
                "conferenceId": obj.get("conferenceId"),
                "accountId": obj.get("accountId"),
                "alias": obj.get("alias"),
                "playBeep": obj.get("playBeep"),
                "record": obj.get("record"),
                "status": obj.get("status"),
                "waitUrl": obj.get("waitUrl"),
                "actionUrl": obj.get("actionUrl"),
                "statusCallbackUrl": obj.get("statusCallbackUrl"),
                "subresourceUris": obj.get("subresourceUris"),
            }
        )
        return _obj
